==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/EmptyDirVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EmptyDirVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.EmptyDirVolumeSource,io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceBuilder>{
  public EmptyDirVolumeSourceBuilder() {
    this(false);
  }
  public EmptyDirVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new EmptyDirVolumeSource(), validationEnabled);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EmptyDirVolumeSource(), validationEnabled);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance) {
    this(fluent, instance, false);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMedium(instance.getMedium()); 
    fluent.withSizeLimit(instance.getSizeLimit()); 
    this.validationEnabled = validationEnabled; 
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance) {
    this(instance,false);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMedium(instance.getMedium()); 
    this.withSizeLimit(instance.getSizeLimit()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSource build() {
    EmptyDirVolumeSource buildable = new EmptyDirVolumeSource(fluent.getMedium(),fluent.getSizeLimit());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EmptyDirVolumeSourceBuilder that = (EmptyDirVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/EmptyDirVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EmptyDirVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.EmptyDirVolumeSource,io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceBuilder>{
  public EmptyDirVolumeSourceBuilder() {
    this(false);
  }
  public EmptyDirVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new EmptyDirVolumeSource(), validationEnabled);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EmptyDirVolumeSource(), validationEnabled);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance) {
    this(fluent, instance, false);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMedium(instance.getMedium()); 
    fluent.withSizeLimit(instance.getSizeLimit()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance) {
    this(instance,false);
  }
  public EmptyDirVolumeSourceBuilder(io.fabric8.kubernetes.api.model.EmptyDirVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMedium(instance.getMedium()); 
    this.withSizeLimit(instance.getSizeLimit()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.EmptyDirVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.EmptyDirVolumeSource build() {
    EmptyDirVolumeSource buildable = new EmptyDirVolumeSource(fluent.getMedium(),fluent.getSizeLimit());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EmptyDirVolumeSourceBuilder that = (EmptyDirVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
